@@ -7,6 +7,7 @@ from django.utils.translation import ugettext_lazy as _
 # keep imports
 from django_geoip import ipgeobase_settings, geoip_settings
 
+
 class Country(models.Model):
     """ One country per row, contains country code and country name (TBD, #2)
     """
@@ -126,7 +127,7 @@ class GeoLocationFascade(models.Model):
         return NotImplemented
 
     @classmethod
-    def get_availabe_locations(cls):
+    def get_available_locations(cls):
         """
         Return all locations available for users to select in frontend
 
